# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMASKDUMP_METADATA = Metadata(
    id="1af6dba5a41109de0e8ac9966c8bb6bae92d9c35.boutiques",
    name="3dmaskdump",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmaskdumpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmaskdump(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output ASCII file with voxel values"""


def v_3dmaskdump(
    input_files: list[InputPathType],
    calc_mask_opts: str | None = None,
    output_filename: str | None = None,
    nball_coords: str | None = None,
    quiet_mode: bool = False,
    runner: Runner | None = None,
) -> V3dmaskdumpOutputs:
    """
    Outputs voxel values from AFNI datasets satisfying mask criteria to an ASCII
    file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dmaskdump.html
    
    Args:
        input_files: Input datasets to dump voxel values.
        calc_mask_opts: Execute options enclosed as a 3dcalc-like program to\
            produce a mask from the resulting 3D brick.
        output_filename: Write output to specified file.
        nball_coords: Put a ball (sphere) mask at LPI/SPM coordinates (x,y,z)\
            with radius r.
        quiet_mode: Do not print progress messages to stderr.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmaskdumpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMASKDUMP_METADATA)
    cargs = []
    cargs.append("3dmaskdump")
    if calc_mask_opts is not None:
        cargs.extend([
            "-cmask",
            calc_mask_opts
        ])
    if output_filename is not None:
        cargs.extend([
            "-o",
            output_filename
        ])
    if nball_coords is not None:
        cargs.extend([
            "-nball",
            nball_coords
        ])
    if quiet_mode:
        cargs.append("-quiet")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V3dmaskdumpOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[OUTPUT_FILENAME]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmaskdumpOutputs",
    "V_3DMASKDUMP_METADATA",
    "v_3dmaskdump",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TCKCONVERT_METADATA = Metadata(
    id="ba4f3995bed0c0902ec8af62c1dd4affcb553184.boutiques",
    name="tckconvert",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TckconvertConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TckconvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tckconvert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output track file."""


def tckconvert(
    input_: str,
    output: str,
    scanner2voxel: InputPathType | None = None,
    scanner2image: InputPathType | None = None,
    voxel2scanner: InputPathType | None = None,
    image2scanner: InputPathType | None = None,
    sides: int | None = None,
    increment: int | None = None,
    dec: bool = False,
    radius: float | None = None,
    ascii_: bool = False,
    binary: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TckconvertConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TckconvertOutputs:
    """
    Convert between different track file formats.
    
    The program currently supports MRtrix .tck files (input/output), ascii text
    files (input/output), VTK polydata files (input/output), and RenderMan RIB
    (export only).
    
    Note that ascii files will be stored with one streamline per numbered file.
    To support this, the command will use the multi-file numbering syntax, where
    square brackets denote the position of the numbering for the files, for
    example:
    
    $ tckconvert input.tck output-'[]'.txt
    
    will produce files named output-0000.txt, output-0001.txt, output-0002.txt,
    ...
    
    References:
    
    .
    
    Author: Daan Christiaens (daan.christiaens@kcl.ac.uk), J-Donald Tournier
    (jdtournier@gmail.com), Philip Broser (philip.broser@me.com), Daniel Blezek
    (daniel.blezek@gmail.com).
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/tckconvert.html
    
    Args:
        input_: the input track file.
        output: the output track file.
        scanner2voxel: if specified, the properties of this image will be used\
            to convert track point positions from real (scanner) coordinates into\
            voxel coordinates.
        scanner2image: if specified, the properties of this image will be used\
            to convert track point positions from real (scanner) coordinates into\
            image coordinates (in mm).
        voxel2scanner: if specified, the properties of this image will be used\
            to convert track point positions from voxel coordinates into real\
            (scanner) coordinates.
        image2scanner: if specified, the properties of this image will be used\
            to convert track point positions from image coordinates (in mm) into\
            real (scanner) coordinates.
        sides: number of sides for streamlines.
        increment: generate streamline points at every (increment) points.
        dec: add DEC as a primvar.
        radius: radius of the streamlines.
        ascii_: write an ASCII VTK file (this is the default).
        binary: write a binary VTK file.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TckconvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TCKCONVERT_METADATA)
    cargs = []
    cargs.append("tckconvert")
    if scanner2voxel is not None:
        cargs.extend([
            "-scanner2voxel",
            execution.input_file(scanner2voxel)
        ])
    if scanner2image is not None:
        cargs.extend([
            "-scanner2image",
            execution.input_file(scanner2image)
        ])
    if voxel2scanner is not None:
        cargs.extend([
            "-voxel2scanner",
            execution.input_file(voxel2scanner)
        ])
    if image2scanner is not None:
        cargs.extend([
            "-image2scanner",
            execution.input_file(image2scanner)
        ])
    if sides is not None:
        cargs.extend([
            "-sides",
            str(sides)
        ])
    if increment is not None:
        cargs.extend([
            "-increment",
            str(increment)
        ])
    if dec:
        cargs.append("-dec")
    if radius is not None:
        cargs.extend([
            "-radius",
            str(radius)
        ])
    if ascii_:
        cargs.append("-ascii")
    if binary:
        cargs.append("-binary")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(input_)
    cargs.append(output)
    ret = TckconvertOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TCKCONVERT_METADATA",
    "TckconvertConfig",
    "TckconvertOutputs",
    "tckconvert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SUMA_METADATA = Metadata(
    id="ab82cac109ef47be190dcdcd83a806490c935c41.boutiques",
    name="suma",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SumaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `suma(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def suma(
    runner: Runner | None = None,
) -> SumaOutputs:
    """
    SUMA: Surface Mapper for visualization and analysis of brain data.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/suma.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SumaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SUMA_METADATA)
    cargs = []
    cargs.append("suma")
    cargs.append("[MODE]")
    cargs.append("[OPTIONS]")
    ret = SumaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SUMA_METADATA",
    "SumaOutputs",
    "suma",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_TO_SURF_METADATA = Metadata(
    id="6b2cd55fafe712416f2f72d25f8e8c236eaf75c1.boutiques",
    name="SurfToSurf",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfToSurfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_to_surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file in 1D format"""


def surf_to_surf(
    make_consistent: bool = False,
    runner: Runner | None = None,
) -> SurfToSurfOutputs:
    """
    Interpolate data from one surface to another.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfToSurf.html
    
    Args:
        make_consistent: Force a consistency check and correct triangle\
            orientation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfToSurfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_TO_SURF_METADATA)
    cargs = []
    cargs.append("SurfToSurf")
    cargs.append("<-i_TYPE")
    cargs.append("S1>")
    cargs.append("[<-sv")
    cargs.append("SV1>]")
    cargs.append("<-i_TYPE")
    cargs.append("S2>")
    cargs.append("[<-sv")
    cargs.append("SV1>]")
    cargs.append("[<-prefix")
    cargs.append("PREFIX>]")
    cargs.append("[<-output_params")
    cargs.append("PARAM_LIST>]")
    cargs.append("[<-node_indices")
    cargs.append("NODE_INDICES>]")
    cargs.append("[<-proj_dir")
    cargs.append("PROJ_DIR>]")
    cargs.append("[<-data")
    cargs.append("DATA>]")
    cargs.append("[<-node_debug")
    cargs.append("NODE>]")
    cargs.append("[<-debug")
    cargs.append("DBG_LEVEL>]")
    if make_consistent:
        cargs.append("-make_consistent")
    cargs.append("[<-dset")
    cargs.append("DSET>]")
    cargs.append("[<-mapfile")
    cargs.append("MAP_INFO>]")
    ret = SurfToSurfOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[PREFIX].1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_TO_SURF_METADATA",
    "SurfToSurfOutputs",
    "surf_to_surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ACOST_METADATA = Metadata(
    id="a26f72fc3f30ed24d5404341c23d8a193b525fda.boutiques",
    name="3dAcost",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAcostOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_acost(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_head: OutputPathType
    """Output aligned dataset (HEAD file)"""
    output_brik: OutputPathType
    """Output aligned dataset (BRIK file)"""


def v_3d_acost(
    infile: InputPathType,
    basefile: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> V3dAcostOutputs:
    """
    Allineate dataset to a base dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAcost.html
    
    Args:
        infile: Input dataset for allineation.
        basefile: Base dataset for allineation.
        outfile: Prefix for the output dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAcostOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ACOST_METADATA)
    cargs = []
    cargs.append("3dAllineate")
    cargs.append(execution.input_file(infile))
    cargs.append("-base")
    cargs.extend([
        "-base",
        execution.input_file(basefile)
    ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        outfile
    ])
    cargs.append("[OTHER_OPTIONS]")
    ret = V3dAcostOutputs(
        root=execution.output_file("."),
        output_head=execution.output_file(outfile + "+orig.HEAD"),
        output_brik=execution.output_file(outfile + "+orig.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAcostOutputs",
    "V_3D_ACOST_METADATA",
    "v_3d_acost",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TSORT_METADATA = Metadata(
    id="c6a7c18dabcbb7f2f94ef090dbd4a2a836fa72c1.boutiques",
    name="3dTsort",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTsortOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tsort(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType | None
    """Main default output of 3dTsort"""


def v_3d_tsort(
    input_file: InputPathType,
    prefix: str | None = None,
    dec: bool = False,
    rank: bool = False,
    ind: bool = False,
    val: bool = False,
    random_: bool = False,
    ranfft: bool = False,
    randft: bool = False,
    datum: str | None = None,
    runner: Runner | None = None,
) -> V3dTsortOutputs:
    """
    Sorts each voxel in a dataset and produces a new dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTsort.html
    
    Args:
        input_file: Input dataset to be sorted.
        prefix: Prefix for the output dataset.
        dec: Sort into decreasing order.
        rank: Output rank instead of sorted values; ranks range from 1 to Nvals.
        ind: Output sorting index (0 to Nvals -1).
        val: Output sorted values (default).
        random_: Randomly shuffle (permute) the time points in each voxel.
        ranfft: Randomize each time series by scrambling the FFT phase.
        randft: Randomize each time series by scrambling the DFT phase.
        datum: Coerce the output data to be stored as the given type (byte,\
            short, or float).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTsortOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TSORT_METADATA)
    cargs = []
    cargs.append("3dTsort")
    cargs.append(execution.input_file(input_file))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if dec:
        cargs.append("-dec")
    if rank:
        cargs.append("-rank")
    if ind:
        cargs.append("-ind")
    if val:
        cargs.append("-val")
    if random_:
        cargs.append("-random")
    if ranfft:
        cargs.append("-ranFFT")
    if randft:
        cargs.append("-ranDFT")
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    ret = V3dTsortOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTsortOutputs",
    "V_3D_TSORT_METADATA",
    "v_3d_tsort",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GEN_GROUP_COMMAND_PY_METADATA = Metadata(
    id="51c3095191f9344439630ab4bd49fe90d933b15f.boutiques",
    name="gen_group_command.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GenGroupCommandPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gen_group_command_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_script: OutputPathType | None
    """The generated command script file"""


def gen_group_command_py(
    command_name: str,
    datasets: list[str],
    prefix: str | None = None,
    set_labels: list[str] | None = None,
    subj_prefix: str | None = None,
    subj_suffix: str | None = None,
    subs_betas: list[str] | None = None,
    subs_tstats: list[str] | None = None,
    type_: str | None = None,
    verb: str | None = None,
    write_script: str | None = None,
    other_options: list[str] | None = None,
    runner: Runner | None = None,
) -> GenGroupCommandPyOutputs:
    """
    Generate group analysis command scripts by parsing wildcard-based lists of input
    datasets.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/gen_group_command.py.html
    
    Args:
        command_name: Resulting command, such as 3dttest++.
        datasets: List of datasets, can be used multiple times for different\
            groups.
        prefix: Prefix for the output file names.
        set_labels: Labels corresponding to datasets entries.
        subj_prefix: Prefix for subject names.
        subj_suffix: Suffix for subject names.
        subs_betas: Sub-bricks for beta weights.
        subs_tstats: Sub-bricks for t-stats (3dMEMA).
        type_: Specify the type of test to perform.
        verb: Set the verbosity level.
        write_script: Write command script to specified file name.
        other_options: List of options to pass along to result.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GenGroupCommandPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GEN_GROUP_COMMAND_PY_METADATA)
    cargs = []
    cargs.append("gen_group_command.py")
    cargs.extend([
        "-command",
        command_name
    ])
    cargs.extend([
        "-dsets",
        *datasets
    ])
    cargs.append("[OPTIONS]")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if set_labels is not None:
        cargs.extend([
            "-set_labels",
            *set_labels
        ])
    if subj_prefix is not None:
        cargs.extend([
            "-subj_prefix",
            subj_prefix
        ])
    if subj_suffix is not None:
        cargs.extend([
            "-subj_suffix",
            subj_suffix
        ])
    if subs_betas is not None:
        cargs.extend([
            "-subs_betas",
            *subs_betas
        ])
    if subs_tstats is not None:
        cargs.extend([
            "-subs_tstats",
            *subs_tstats
        ])
    if type_ is not None:
        cargs.extend([
            "-type",
            type_
        ])
    if verb is not None:
        cargs.extend([
            "-verb",
            verb
        ])
    if write_script is not None:
        cargs.extend([
            "-write_script",
            write_script
        ])
    if other_options is not None:
        cargs.extend([
            "-options",
            *other_options
        ])
    ret = GenGroupCommandPyOutputs(
        root=execution.output_file("."),
        output_script=execution.output_file(write_script) if (write_script is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GEN_GROUP_COMMAND_PY_METADATA",
    "GenGroupCommandPyOutputs",
    "gen_group_command_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMG2STDCOORD_METADATA = Metadata(
    id="ebbbc78d99eb06d9c9f6e6f5f7ea7f7feab66bdd.boutiques",
    name="img2stdcoord",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Img2stdcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `img2stdcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def img2stdcoord(
    coordinate_file: str,
    runner: Runner | None = None,
) -> Img2stdcoordOutputs:
    """
    Transforms image coordinates using standard space transformations.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        coordinate_file: Filename containing coordinates. If '-' is used,\
            coordinates are read from standard input.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Img2stdcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMG2STDCOORD_METADATA)
    cargs = []
    cargs.append("img2stdcoord")
    cargs.append("[OPTIONS]")
    cargs.append(coordinate_file)
    ret = Img2stdcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMG2STDCOORD_METADATA",
    "Img2stdcoordOutputs",
    "img2stdcoord",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AUTO_WARP_PY_METADATA = Metadata(
    id="991ef18315e37d7887a5bb0048caaf474cfd252d.boutiques",
    name="auto_warp.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AutoWarpPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `auto_warp_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def auto_warp_py(
    base: InputPathType,
    input_: InputPathType,
    skull_strip_input: bool = False,
    qblur: str | None = None,
    qworkhard: str | None = None,
    qw_opts: str | None = None,
    keep_rm_files: bool = False,
    prep_only: bool = False,
    help_: bool = False,
    hview: bool = False,
    limited_help: bool = False,
    option_help: bool = False,
    version: bool = False,
    ver: bool = False,
    verb: bool = False,
    save_script: bool = False,
    skip_affine: bool = False,
    skull_strip_base: bool = False,
    ex_mode: str | None = None,
    overwrite: bool = False,
    suffix: str | None = None,
    child_anat: str | None = None,
    warp_dxyz: float | None = None,
    affine_dxyz: float | None = None,
    affine_input_xmat: str | None = None,
    smooth_anat: bool = False,
    smooth_base: bool = False,
    unifize_input: bool = False,
    output_dir: str | None = None,
    followers: str | None = None,
    affine_followers_xmat: str | None = None,
    skullstrip_opts: str | None = None,
    at_opts: str | None = None,
    runner: Runner | None = None,
) -> AutoWarpPyOutputs:
    """
    Nonlinear registration tool.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/auto_warp.py.html
    
    Args:
        base: Name of reference or template volume.
        input_: Name of dataset to be registered.
        skull_strip_input: Do not skullstrip input dataset.
        qblur: Specify 3dQwarp blurs for base and source volumes.
        qworkhard: Set the two values for 3dQwarp's -workhard option.
        qw_opts: Pass all of OPTS as extra options directly to 3dQwarp.
        keep_rm_files: Don't delete any of the temporary files created.
        prep_only: Do preprocessing steps only without alignment.
        help_: Display help message.
        hview: Display help message in a text editor.
        limited_help: Display limited help message.
        option_help: Display help for all available options.
        version: Show version number and exit.
        ver: Show version number and exit.
        verb: Be verbose in messages and options.
        save_script: Save executed script in given file.
        skip_affine: Skip the affine registration process.
        skull_strip_base: Do not skullstrip base/template dataset.
        ex_mode: Command execution mode: quiet, echo, dry_run, script.
        overwrite: Overwrite existing files.
        suffix: Suffix to add to output files.
        child_anat: Names of child anatomical datasets.
        warp_dxyz: Resolution used for computing warp (cubic only).
        affine_dxyz: Resolution used for computing initial transform (cubic\
            only).
        affine_input_xmat: Affine transform to put input in standard space.\
            Special values are: 'AUTO' to use @auto_tlrc, 'ID' to do nothing,\
            'FILE.1D' for a pre-computed matrix FILE.1D.
        smooth_anat: Smooth anatomy before registration.
        smooth_base: Smooth template before registration.
        unifize_input: Unifize the input or not.
        output_dir: Set directory for output datasets.
        followers: Specify follower datasets.
        affine_followers_xmat: Specify follower datasets' affine transforms.
        skullstrip_opts: 3dSkullstrip miscellaneous options.
        at_opts: @auto_tlrc miscellaneous options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AutoWarpPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AUTO_WARP_PY_METADATA)
    cargs = []
    cargs.append("auto_warp.py")
    cargs.append("-base")
    cargs.append(execution.input_file(base))
    cargs.append("-input")
    cargs.append(execution.input_file(input_))
    if skull_strip_input:
        cargs.append("-skull_strip_input")
    if qblur is not None:
        cargs.extend([
            "-qblur",
            qblur
        ])
    if qworkhard is not None:
        cargs.extend([
            "-qworkhard",
            qworkhard
        ])
    if qw_opts is not None:
        cargs.extend([
            "-qw_opts",
            qw_opts
        ])
    if keep_rm_files:
        cargs.append("-keep_rm_files")
    if prep_only:
        cargs.append("-prep_only")
    if help_:
        cargs.append("-help")
    if hview:
        cargs.append("-hview")
    if limited_help:
        cargs.append("-limited_help")
    if option_help:
        cargs.append("-option_help")
    if version:
        cargs.append("-version")
    if ver:
        cargs.append("-ver")
    if verb:
        cargs.append("-verb")
    if save_script:
        cargs.append("-save_script")
    if skip_affine:
        cargs.append("-skip_affine")
    if skull_strip_base:
        cargs.append("-skull_strip_base")
    if ex_mode is not None:
        cargs.extend([
            "-ex_mode",
            ex_mode
        ])
    if overwrite:
        cargs.append("-overwrite")
    if suffix is not None:
        cargs.extend([
            "-suffix",
            suffix
        ])
    if child_anat is not None:
        cargs.extend([
            "-child_anat",
            child_anat
        ])
    if warp_dxyz is not None:
        cargs.extend([
            "-warp_dxyz",
            str(warp_dxyz)
        ])
    if affine_dxyz is not None:
        cargs.extend([
            "-affine_dxyz",
            str(affine_dxyz)
        ])
    if affine_input_xmat is not None:
        cargs.extend([
            "-affine_input_xmat",
            affine_input_xmat
        ])
    if smooth_anat:
        cargs.append("-smooth_anat")
    if smooth_base:
        cargs.append("-smooth_base")
    if unifize_input:
        cargs.append("-unifize_input")
    if output_dir is not None:
        cargs.extend([
            "-output_dir",
            output_dir
        ])
    if followers is not None:
        cargs.extend([
            "-followers",
            followers
        ])
    if affine_followers_xmat is not None:
        cargs.extend([
            "-affine_followers_xmat",
            affine_followers_xmat
        ])
    if skullstrip_opts is not None:
        cargs.extend([
            "-skullstrip_opts",
            skullstrip_opts
        ])
    if at_opts is not None:
        cargs.extend([
            "-at_opts",
            at_opts
        ])
    ret = AutoWarpPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AUTO_WARP_PY_METADATA",
    "AutoWarpPyOutputs",
    "auto_warp_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DSETSTAT2P_METADATA = Metadata(
    id="ed9eb51fe358c9554d3224bb89356e67ecbcfa05.boutiques",
    name="dsetstat2p",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Dsetstat2pOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dsetstat2p(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output p-value or stat value"""


def dsetstat2p(
    dataset: str,
    statval: float,
    one_sided: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> Dsetstat2pOutputs:
    """
    Converts a statistic to a p-value with reference to a particular dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/dsetstat2p.html
    
    Args:
        dataset: Specify a dataset DDD and, if it has multiple sub-bricks, the\
            [i]th subbrick with the statistic of interest MUST be selected\
            explicitly; note the use of quotation marks around the brick selector\
            (because of the square-brackets). Note that 'i' can be either a number\
            of a string label selector.
        statval: Input stat-value S, which MUST be in the interval [0,\
            infinity).
        one_sided: Choose one-sided or bi-sided/two-sided testing.
        quiet: An optional flag so that output ONLY the final statistic value\
            output to standard output; this can be then be viewed, redirected to a\
            text file or saved as a shell variable. (Default: display supplementary\
            text.).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Dsetstat2pOutputs`).
    """
    if not (0 <= statval): 
        raise ValueError(f"'statval' must be greater than 0 <= x but was {statval}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(DSETSTAT2P_METADATA)
    cargs = []
    cargs.append("dsetstat2p")
    cargs.append(dataset)
    cargs.append(str(statval))
    if one_sided:
        cargs.append("-1sided")
    if quiet:
        cargs.append("-quiet")
    ret = Dsetstat2pOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DSETSTAT2P_METADATA",
    "Dsetstat2pOutputs",
    "dsetstat2p",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_COORDINATES_TO_METRIC_METADATA = Metadata(
    id="b5f9d857e4da9eaee4f4d47edd03a799151c7100.boutiques",
    name="surface-coordinates-to-metric",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceCoordinatesToMetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_coordinates_to_metric(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def surface_coordinates_to_metric(
    surface: InputPathType,
    metric_out: str,
    runner: Runner | None = None,
) -> SurfaceCoordinatesToMetricOutputs:
    """
    Make metric file of surface coordinates.
    
    Puts the coordinates of the surface into a 3-map metric file, as x, y, z.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to use the coordinates of.
        metric_out: the output metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCoordinatesToMetricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_COORDINATES_TO_METRIC_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-coordinates-to-metric")
    cargs.append(execution.input_file(surface))
    cargs.append(metric_out)
    ret = SurfaceCoordinatesToMetricOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_COORDINATES_TO_METRIC_METADATA",
    "SurfaceCoordinatesToMetricOutputs",
    "surface_coordinates_to_metric",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_INTRACRANIAL_METADATA = Metadata(
    id="9fa3ac80b0a74be0ff2b130a1522990d5d89a98f.boutiques",
    name="3dIntracranial",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dIntracranialOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_intracranial(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmented_image: OutputPathType
    """Output file containing segmented image"""


def v_3d_intracranial(
    infile: InputPathType,
    prefix: str,
    min_val: float | None = None,
    max_val: float | None = None,
    min_conn: float | None = None,
    max_conn: float | None = None,
    no_smooth: bool = False,
    mask: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dIntracranialOutputs:
    """
    Performs automatic segmentation of intracranial region.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dIntracranial.html
    
    Args:
        infile: Filename of anat dataset to be segmented.
        prefix: Prefix name for file to contain segmented image.
        min_val: Minimum voxel intensity limit. Default is internal PDF\
            estimate for lower bound.
        max_val: Maximum voxel intensity limit. Default is internal PDF\
            estimate for upper bound.
        min_conn: Minimum voxel connectivity to enter. Default is 4.
        max_conn: Maximum voxel connectivity to leave. Default is 2.
        no_smooth: Suppress spatial smoothing of segmentation mask.
        mask: Generate functional image mask (complement). Default is to\
            generate anatomical image.
        quiet: Suppress output to screen.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dIntracranialOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_INTRACRANIAL_METADATA)
    cargs = []
    cargs.append("3dIntracranial")
    cargs.append("-anat")
    cargs.append(execution.input_file(infile))
    cargs.append("-prefix")
    cargs.append(prefix)
    if min_val is not None:
        cargs.extend([
            "-min_val",
            str(min_val)
        ])
    if max_val is not None:
        cargs.extend([
            "-max_val",
            str(max_val)
        ])
    if min_conn is not None:
        cargs.extend([
            "-min_conn",
            str(min_conn)
        ])
    if max_conn is not None:
        cargs.extend([
            "-max_conn",
            str(max_conn)
        ])
    if no_smooth:
        cargs.append("-nosmooth")
    if mask:
        cargs.append("-mask")
    if quiet:
        cargs.append("-quiet")
    ret = V3dIntracranialOutputs(
        root=execution.output_file("."),
        segmented_image=execution.output_file(prefix + "+orig"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dIntracranialOutputs",
    "V_3D_INTRACRANIAL_METADATA",
    "v_3d_intracranial",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_FILTER_DWIS_METADATA = Metadata(
    id="357671a27361138fb75b7f697cceebf0bdad33a5.boutiques",
    name="fat_proc_filter_dwis",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcFilterDwisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_filter_dwis(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    filtered_dwi: OutputPathType
    """Filtered 4D DWI dataset."""
    filtered_bvecs: OutputPathType
    """Filtered gradient file matching input format."""
    filtered_bvals: OutputPathType
    """Filtered b-values file, if provided."""


def fat_proc_filter_dwis(
    input_dwi: InputPathType,
    input_gradient: InputPathType,
    select_string: str,
    output_prefix: str,
    runner: Runner | None = None,
) -> FatProcFilterDwisOutputs:
    """
    Filter out user-found and user-defined bad volumes from DWI data sets.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_proc_filter_dwis.html
    
    Args:
        input_dwi: Name of a 4D file of DWIs (required).
        input_gradient: Bvec/bmat file from the gradients. Required. One of\
            these options must be used: -in_col_matA, -in_col_matT, -in_col_vec,\
            -in_row_vec.
        select_string: A string of indices and index ranges for selecting which\
            volumes/grads/bvals to keep. This string gets applied to the volume,\
            bval|bvec|bmat files for an input set. Either this or -select_file is\
            required.
        output_prefix: Output prefix for all the volumes and text files.\
            Required.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcFilterDwisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_FILTER_DWIS_METADATA)
    cargs = []
    cargs.append("fat_proc_filter_dwis")
    cargs.append("-in_dwi")
    cargs.extend([
        "-in_dwi",
        execution.input_file(input_dwi)
    ])
    cargs.extend([
        "-in_col_matA|-in_col_matT|-in_col_vec|-in_row_vec",
        execution.input_file(input_gradient)
    ])
    cargs.append("-select")
    cargs.extend([
        "-select",
        select_string
    ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    cargs.append("[OPTIONAL_PARAMS]")
    ret = FatProcFilterDwisOutputs(
        root=execution.output_file("."),
        filtered_dwi=execution.output_file(output_prefix + "_filtered.nii.gz"),
        filtered_bvecs=execution.output_file(output_prefix + "_filtered.bvecs"),
        filtered_bvals=execution.output_file(output_prefix + "_filtered.bvals"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_FILTER_DWIS_METADATA",
    "FatProcFilterDwisOutputs",
    "fat_proc_filter_dwis",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SCALE_TO_MAP_METADATA = Metadata(
    id="61d30c2310aeeb2b815339618faadb24ade782f8.boutiques",
    name="ScaleToMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ScaleToMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `scale_to_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def scale_to_map(
    input_file: InputPathType,
    icol: float,
    vcol: float,
    runner: Runner | None = None,
) -> ScaleToMapOutputs:
    """
    Tool to scale values to a color map.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/ScaleToMap.html
    
    Args:
        input_file: Input file in 1D formatted ascii containing node values.
        icol: Index of node index column (-1 if node index is implicit).
        vcol: Index of node value column.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ScaleToMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SCALE_TO_MAP_METADATA)
    cargs = []
    cargs.append("ScaleToMap")
    cargs.append(execution.input_file(input_file))
    cargs.append(str(icol))
    cargs.append(str(vcol))
    cargs.append("[OPTIONAL_PARAMETERS]")
    ret = ScaleToMapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SCALE_TO_MAP_METADATA",
    "ScaleToMapOutputs",
    "scale_to_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SIMULATE_MOTION_METADATA = Metadata(
    id="29610b1a1e2e528bee711b23ea7ec7ab12c28c38.boutiques",
    name="@simulate_motion",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSimulateMotionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__simulate_motion(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    simulated_motion_output: OutputPathType
    """Motion simulated EPI time series"""


def v__simulate_motion(
    epi: InputPathType,
    motion_file: InputPathType,
    runner: Runner | None = None,
) -> VSimulateMotionOutputs:
    """
    Create simulated motion time series in an EPI dataset based on the provided
    motion parameters and an input volume.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@simulate_motion.html
    
    Args:
        epi: Input EPI volume or time series (only a volreg base is needed,\
            though more is okay).
        motion_file: Motion parameter file (as output by 3dvolreg).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSimulateMotionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SIMULATE_MOTION_METADATA)
    cargs = []
    cargs.append("@simulate_motion")
    cargs.append("[options]")
    cargs.append("-epi")
    cargs.extend([
        "-epi",
        execution.input_file(epi)
    ])
    cargs.append("-motion_file")
    cargs.extend([
        "-motion_file",
        execution.input_file(motion_file)
    ])
    ret = VSimulateMotionOutputs(
        root=execution.output_file("."),
        simulated_motion_output=execution.output_file("[PREFIX]_simulated_motion.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSimulateMotionOutputs",
    "V__SIMULATE_MOTION_METADATA",
    "v__simulate_motion",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSWAPDIM_METADATA = Metadata(
    id="3a2f4f099d72c1eac28d03d542e8eff1c68e2239.boutiques",
    name="fslswapdim",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslswapdimOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslswapdim(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType | None
    """Output image with swapped dimensions"""


def fslswapdim(
    input_file: InputPathType,
    axis_a: str,
    axis_b: str,
    axis_c: str,
    output_file: str | None = None,
    runner: Runner | None = None,
) -> FslswapdimOutputs:
    """
    Swap dimensions of an image volume.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        input_file: Input image (e.g. img.nii.gz).
        axis_a: New x-axis dimension (e.g., -x, x, RL, etc.).
        axis_b: New y-axis dimension (e.g., -y, y, PA, etc.).
        axis_c: New z-axis dimension (e.g., -z, z, IS, etc.).
        output_file: Output image (e.g., output.nii.gz). If not specified, the\
            equivalent transformation matrix is written to the standard output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslswapdimOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSWAPDIM_METADATA)
    cargs = []
    cargs.append("fslswapdim")
    cargs.append(execution.input_file(input_file))
    cargs.append(axis_a)
    cargs.append(axis_b)
    cargs.append(axis_c)
    if output_file is not None:
        cargs.append(output_file)
    ret = FslswapdimOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSWAPDIM_METADATA",
    "FslswapdimOutputs",
    "fslswapdim",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__MOVE_TO_SERIES_DIRS_METADATA = Metadata(
    id="8517e78bc427c837d03316920c32177dfecc5fe3.boutiques",
    name="@move.to.series.dirs",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VMoveToSeriesDirsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__move_to_series_dirs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__move_to_series_dirs(
    runner: Runner | None = None,
) -> VMoveToSeriesDirsOutputs:
    """
    Partition DICOM files into series directories by copying or moving them to new
    series directories.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@move.to.series.dirs.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VMoveToSeriesDirsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__MOVE_TO_SERIES_DIRS_METADATA)
    cargs = []
    cargs.append("@move.to.series.dirs")
    cargs.append("[OPTIONS]")
    cargs.append("DICOM_FILES")
    ret = VMoveToSeriesDirsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VMoveToSeriesDirsOutputs",
    "V__MOVE_TO_SERIES_DIRS_METADATA",
    "v__move_to_series_dirs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MP_DIFFPOW_SH_METADATA = Metadata(
    id="47d1342f89677016a0725a5ada2d4a84149c45e9.boutiques",
    name="mp_diffpow.sh",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MpDiffpowShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mp_diffpow_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """File containing squared motion parameters, temporal difference of motion
    parameters, and squared differenced values."""


def mp_diffpow_sh(
    reg_file: InputPathType,
    diff_reg_file: str,
    runner: Runner | None = None,
) -> MpDiffpowShOutputs:
    """
    Generates a file with specific motion parameter calculations useful for
    accounting for 'spin history' effects and other variations not accounted for by
    motion correction.
    
    Author: Unknown
    
    Args:
        reg_file: Input file containing registration parameters (e.g.,\
            regparam.dat).
        diff_reg_file: Output file with differenced registration parameters\
            (e.g., diffregparam.dat).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MpDiffpowShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MP_DIFFPOW_SH_METADATA)
    cargs = []
    cargs.append("mp_diff")
    cargs.append(execution.input_file(reg_file))
    cargs.append(diff_reg_file)
    ret = MpDiffpowShOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(diff_reg_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MP_DIFFPOW_SH_METADATA",
    "MpDiffpowShOutputs",
    "mp_diffpow_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SCENE_FILE_MERGE_METADATA = Metadata(
    id="c5a86083ec4db99dc4360c618252324b7f95a8a1.boutiques",
    name="scene-file-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class SceneFileMergeUpTo:
    """
    use an inclusive range of scenes.
    """
    last_column: str
    """the number or name of the last scene to include"""
    opt_reverse: bool = False
    """use the range in reverse order"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-up-to")
        cargs.append(self.last_column)
        if self.opt_reverse:
            cargs.append("-reverse")
        return cargs


@dataclasses.dataclass
class SceneFileMergeScene:
    """
    specify a scene to use.
    """
    scene: str
    """the scene number or name"""
    up_to: SceneFileMergeUpTo | None = None
    """use an inclusive range of scenes"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-scene")
        cargs.append(self.scene)
        if self.up_to is not None:
            cargs.extend(self.up_to.run(execution))
        return cargs


@dataclasses.dataclass
class SceneFileMergeSceneFile:
    """
    specify a scene file to use scenes from.
    """
    scene_file: str
    """the input scene file"""
    scene: list[SceneFileMergeScene] | None = None
    """specify a scene to use"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-scene-file")
        cargs.append(self.scene_file)
        if self.scene is not None:
            cargs.extend([a for c in [s.run(execution) for s in self.scene] for a in c])
        return cargs


class SceneFileMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `scene_file_merge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def scene_file_merge(
    scene_file_out: str,
    scene_file: list[SceneFileMergeSceneFile] | None = None,
    runner: Runner | None = None,
) -> SceneFileMergeOutputs:
    """
    Rearrange scenes into a new file.
    
    Takes one or more scene files and constructs a new scene file by
    concatenating specified scenes from them.
    
    Example: wb_command -scene-file-merge out.scene -scene-file first.scene
    -scene 1 -scene-file second.scene
    
    This example would take the first scene from first.scene, followed by all
    scenes from second.scene, and write these scenes to out.scene.
    
    Author: Washington University School of Medicin
    
    Args:
        scene_file_out: output - the output scene file.
        scene_file: specify a scene file to use scenes from.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SceneFileMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SCENE_FILE_MERGE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-scene-file-merge")
    cargs.append(scene_file_out)
    if scene_file is not None:
        cargs.extend([a for c in [s.run(execution) for s in scene_file] for a in c])
    ret = SceneFileMergeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SCENE_FILE_MERGE_METADATA",
    "SceneFileMergeOutputs",
    "SceneFileMergeScene",
    "SceneFileMergeSceneFile",
    "SceneFileMergeUpTo",
    "scene_file_merge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__NP_METADATA = Metadata(
    id="6a550274134fb45c8a0bbb1e42e5e8aba7b41891.boutiques",
    name="@np",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VNpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__np(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output text file with the appropriate new prefix."""


def v__np(
    prefix: str,
    runner: Runner | None = None,
) -> VNpOutputs:
    """
    Finds an appropriate new prefix to use, given the files you already have in your
    directory. It automatically creates a valid prefix when you are repeatedly
    running similar commands but do not want to delete previous output.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@np.html
    
    Args:
        prefix: The prefix to be checked.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VNpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__NP_METADATA)
    cargs = []
    cargs.append("@np")
    cargs.append(prefix)
    ret = VNpOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("appropriate_prefix.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VNpOutputs",
    "V__NP_METADATA",
    "v__np",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLOAT_SCAN_METADATA = Metadata(
    id="ff43e34ccfb6d75bca9b732f0b330b522d1218c2.boutiques",
    name="float_scan",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FloatScanOutputs(typing.NamedTuple):
    """
    Output object returned when calling `float_scan(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout_file: OutputPathType
    """Output file with illegal values replaced by 0 when -fix flag is used"""


def float_scan(
    input_file: InputPathType,
    fix_illegal_values: bool = False,
    verbose_mode: bool = False,
    skip_count: int | None = None,
    runner: Runner | None = None,
) -> FloatScanOutputs:
    """
    Scans the input file of IEEE floating point numbers for illegal values:
    infinities and not-a-number (NaN) values.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/float_scan.html
    
    Args:
        input_file: Input file containing IEEE floating point numbers.
        fix_illegal_values: Writes a copy of the input file to stdout,\
            replacing illegal values with 0.
        verbose_mode: Verbose mode: print out index of each illegal value.
        skip_count: Skip the first n floating point locations (i.e., the first\
            4*n bytes) in the file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FloatScanOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLOAT_SCAN_METADATA)
    cargs = []
    cargs.append("float_scan")
    if fix_illegal_values:
        cargs.append("-fix")
    if verbose_mode:
        cargs.append("-v")
    if skip_count is not None:
        cargs.extend([
            "-skip",
            str(skip_count)
        ])
    cargs.append(execution.input_file(input_file))
    ret = FloatScanOutputs(
        root=execution.output_file("."),
        stdout_file=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLOAT_SCAN_METADATA",
    "FloatScanOutputs",
    "float_scan",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MCCUTUP_METADATA = Metadata(
    id="38f27698b0fd81106186cbbb3524e89f2b2da116.boutiques",
    name="mccutup",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MccutupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mccutup(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Output file"""


def mccutup(
    input_: InputPathType,
    runner: Runner | None = None,
) -> MccutupOutputs:
    """
    FSL mccutup tool.
    
    Author: FSL
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        input_: Input file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MccutupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MCCUTUP_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/mccutup")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_))
    ret = MccutupOutputs(
        root=execution.output_file("."),
        output=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MCCUTUP_METADATA",
    "MccutupOutputs",
    "mccutup",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_MASK_METADATA = Metadata(
    id="c800dbf5e18e0d79c62bcbe9addf92ea1b420b84.boutiques",
    name="label-mask",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class LabelMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""


def label_mask(
    label: InputPathType,
    mask: InputPathType,
    label_out: str,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> LabelMaskOutputs:
    """
    Mask a label file.
    
    By default, the output label is a copy of the input label, but with the
    'unused' label wherever the mask metric is zero or negative. if -column is
    specified, the output contains only one column, the masked version of the
    specified input column.
    
    Author: Washington University School of Medicin
    
    Args:
        label: the label file to mask.
        mask: the mask metric.
        label_out: the output label file.
        opt_column_column: select a single column: the column number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_MASK_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-mask")
    cargs.append(execution.input_file(label))
    cargs.append(execution.input_file(mask))
    cargs.append(label_out)
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    ret = LabelMaskOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(label_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_MASK_METADATA",
    "LabelMaskOutputs",
    "label_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANALYZE_TRACE_METADATA = Metadata(
    id="5a0be7a1c9bbf28c16fb460bf4438ddbf2b839e8.boutiques",
    name="AnalyzeTrace",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AnalyzeTraceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `analyze_trace(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def analyze_trace(
    runner: Runner | None = None,
) -> AnalyzeTraceOutputs:
    """
    A program to analyze SUMA (and AFNI's perhaps) stack output for functions that
    return with RETURN without bothering to go on the stack.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/AnalyzeTrace.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnalyzeTraceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANALYZE_TRACE_METADATA)
    cargs = []
    cargs.append("AnalyzeTrace")
    cargs.append("[OPTIONAL_PARAMETERS]")
    cargs.append("FILE")
    ret = AnalyzeTraceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANALYZE_TRACE_METADATA",
    "AnalyzeTraceOutputs",
    "analyze_trace",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MERGE_METADATA = Metadata(
    id="cbb6884a58b75dfd14525a8a1395536bd76c6bd8.boutiques",
    name="merge",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `merge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Merged output file."""


def merge(
    merged_file: str,
    in_files: list[InputPathType],
    dimension: typing.Literal["t", "x", "y", "z", "a"] | None = None,
    dimension_tr: bool = False,
    tr: float | None = None,
    volume_number: int | None = None,
    runner: Runner | None = None,
) -> MergeOutputs:
    """
    Concatenate image files into a single output. This concatenation can be in time,
    or in X, Y or Z. All image dimensions (except for the one being concatenated
    over) must be the same in all input images. For example, this can be used to
    take multiple 3D files (eg as output by SPM) and create a single 4D image file.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        merged_file: Merged output file.
        in_files: A list of images to merge together.
        dimension: 't' or 'x' or 'y' or 'z' or 'a'. Dimension along which to\
            merge, optionally set tr input when dimension is t.
        dimension_tr: Concatenate images in time and set out image tr to final\
            option value.
        tr: Use to specify tr in seconds (default is 1.00 sec), overrides\
            dimension and sets it to tr.
        volume_number: Only use volume <N> from each input file (first volume\
            is 0 and not 1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MERGE_METADATA)
    cargs = []
    cargs.append("fslmerge")
    if dimension is not None:
        cargs.append("-" + dimension)
    if dimension_tr:
        cargs.append("-tr")
    cargs.append(merged_file)
    cargs.extend([execution.input_file(f) for f in in_files])
    if tr is not None:
        cargs.append(str(tr))
    if volume_number is not None:
        cargs.extend([
            "-n",
            str(volume_number)
        ])
    ret = MergeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(merged_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MERGE_METADATA",
    "MergeOutputs",
    "merge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TCKSTATS_METADATA = Metadata(
    id="2e6f7d19387564d069ab548694fef288498b97ad.boutiques",
    name="tckstats",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TckstatsOutput:
    """
    output only the field specified. Multiple such options can be supplied if
    required. Choices are: mean, median, std, min, max, count. Useful for use in
    scripts.
    """
    field: str
    """output only the field specified. Multiple such options can be supplied if
    required. Choices are: mean, median, std, min, max, count. Useful for use in
    scripts."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-output")
        cargs.append(self.field)
        return cargs


@dataclasses.dataclass
class TckstatsConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TckstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tckstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    histogram: OutputPathType | None
    """output a histogram of streamline lengths """
    dump: OutputPathType | None
    """dump the streamlines lengths to a text file """


def tckstats(
    tracks_in: InputPathType,
    output: list[TckstatsOutput] | None = None,
    histogram: str | None = None,
    dump: str | None = None,
    ignorezero: bool = False,
    tck_weights_in: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TckstatsConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TckstatsOutputs:
    """
    Calculate statistics on streamlines lengths.
    
    
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/tckstats.html
    
    Args:
        tracks_in: the input track file.
        output: output only the field specified. Multiple such options can be\
            supplied if required. Choices are: mean, median, std, min, max, count.\
            Useful for use in scripts.
        histogram: output a histogram of streamline lengths.
        dump: dump the streamlines lengths to a text file.
        ignorezero: do not generate a warning if the track file contains\
            streamlines with zero length.
        tck_weights_in: specify a text scalar file containing the streamline\
            weights.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TckstatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TCKSTATS_METADATA)
    cargs = []
    cargs.append("tckstats")
    if output is not None:
        cargs.extend([a for c in [s.run(execution) for s in output] for a in c])
    if histogram is not None:
        cargs.extend([
            "-histogram",
            histogram
        ])
    if dump is not None:
        cargs.extend([
            "-dump",
            dump
        ])
    if ignorezero:
        cargs.append("-ignorezero")
    if tck_weights_in is not None:
        cargs.extend([
            "-tck_weights_in",
            execution.input_file(tck_weights_in)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(tracks_in))
    ret = TckstatsOutputs(
        root=execution.output_file("."),
        histogram=execution.output_file(histogram) if (histogram is not None) else None,
        dump=execution.output_file(dump) if (dump is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TCKSTATS_METADATA",
    "TckstatsConfig",
    "TckstatsOutput",
    "TckstatsOutputs",
    "tckstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_LABEL_PROBABILITY_METADATA = Metadata(
    id="fc29cc0dc8f5a8121f3307010f5444b65ec68ccc.boutiques",
    name="cifti-label-probability",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiLabelProbabilityOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_label_probability(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    probability_dscalar_out: OutputPathType
    """the relative frequencies of each label at each vertex/voxel"""


def cifti_label_probability(
    label_maps: InputPathType,
    probability_dscalar_out: str,
    opt_exclude_unlabeled: bool = False,
    runner: Runner | None = None,
) -> CiftiLabelProbabilityOutputs:
    """
    Find frequency of cifti labels.
    
    This command outputs a set of soft ROIs, one for each label in the input,
    where the value is how many of the input maps had that label at that
    vertex/voxel, divided by the number of input maps.
    
    Author: Washington University School of Medicin
    
    Args:
        label_maps: cifti dlabel file containing individual label maps from\
            many subjects.
        probability_dscalar_out: the relative frequencies of each label at each\
            vertex/voxel.
        opt_exclude_unlabeled: don't make a probability map of the unlabeled\
            key.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelProbabilityOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_PROBABILITY_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-probability")
    cargs.append(execution.input_file(label_maps))
    cargs.append(probability_dscalar_out)
    if opt_exclude_unlabeled:
        cargs.append("-exclude-unlabeled")
    ret = CiftiLabelProbabilityOutputs(
        root=execution.output_file("."),
        probability_dscalar_out=execution.output_file(probability_dscalar_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_LABEL_PROBABILITY_METADATA",
    "CiftiLabelProbabilityOutputs",
    "cifti_label_probability",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_ANAT_METADATA = Metadata(
    id="b97ab58f668ccc4a40c9a2e079146c6b729df253.boutiques",
    name="fsl_anat",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslAnatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_anat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_anat_dir: OutputPathType
    """Output anatomical directory"""


def fsl_anat(
    structural_image: InputPathType | None = None,
    existing_anat_dir: str | None = None,
    runner: Runner | None = None,
) -> FslAnatOutputs:
    """
    A wrapper for FSL tools to process anatomical scans.
    
    Author: FMRIB Software Library (FSL) developers
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/fsl_anat
    
    Args:
        structural_image: Filename of input image (for one image only).
        existing_anat_dir: Directory name for existing .anat directory where\
            this script will be run in place.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslAnatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_ANAT_METADATA)
    cargs = []
    cargs.append("fsl_anat")
    cargs.append("[PARAMS]")
    cargs.append("-i")
    if structural_image is not None:
        cargs.extend([
            "-i",
            execution.input_file(structural_image)
        ])
    cargs.append("-d")
    if existing_anat_dir is not None:
        cargs.extend([
            "-d",
            existing_anat_dir
        ])
    ret = FslAnatOutputs(
        root=execution.output_file("."),
        output_anat_dir=execution.output_file("[OUTPUT_DIR].anat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_ANAT_METADATA",
    "FslAnatOutputs",
    "fsl_anat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRCAT_METADATA = Metadata(
    id="21885e76d810f08df4364284639c8ed0bfacf428.boutiques",
    name="mrcat",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrcatConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image."""


def mrcat(
    image1: InputPathType,
    image2: list[InputPathType],
    output: str,
    axis: int | None = None,
    datatype: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrcatConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrcatOutputs:
    """
    Concatenate several images into one.
    
    
    
    References:
    
    .
    
    Author: J-Donald Tournier (jdtournier@gmail.com) and Robert E. Smith
    (robert.smith@florey.edu.au)
    
    URL: https://mrtrix.readthedocs.io/en/latest/reference/commands/mrcat.html
    
    Args:
        image1: the first input image.
        image2: additional input image(s).
        output: the output image.
        axis: specify axis along which concatenation should be performed. By\
            default, the program will use the last non-singleton, non-spatial axis\
            of any of the input images - in other words axis 3 or whichever axis\
            (greater than 3) of the input images has size greater than one.
        datatype: specify output image data type. Valid choices are: float32,\
            float32le, float32be, float64, float64le, float64be, int64, uint64,\
            int64le, uint64le, int64be, uint64be, int32, uint32, int32le, uint32le,\
            int32be, uint32be, int16, uint16, int16le, uint16le, int16be, uint16be,\
            cfloat32, cfloat32le, cfloat32be, cfloat64, cfloat64le, cfloat64be,\
            int8, uint8, bit.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRCAT_METADATA)
    cargs = []
    cargs.append("mrcat")
    if axis is not None:
        cargs.extend([
            "-axis",
            str(axis)
        ])
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(image1))
    cargs.extend([execution.input_file(f) for f in image2])
    cargs.append(output)
    ret = MrcatOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRCAT_METADATA",
    "MrcatConfig",
    "MrcatOutputs",
    "mrcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SAMP_BIAS_METADATA = Metadata(
    id="9480cbad7a38a99f1c7cad718271beff5166df8e.boutiques",
    name="SampBias",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SampBiasOutputs(typing.NamedTuple):
    """
    Output object returned when calling `samp_bias(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_1_d: OutputPathType
    """Output results in .1D format"""
    out_prefix: OutputPathType | None
    """Output results in a proper surface-based dataset."""


def samp_bias(
    specfile: InputPathType,
    surfname: str,
    outfile: str,
    plimit: float | None = None,
    dlimit: float | None = None,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> SampBiasOutputs:
    """
    SampBias is a tool for sampling bias resultant segments between paired nodes on
    anatomical surfaces.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SampBias.html
    
    Args:
        specfile: Spec file containing input surfaces.
        surfname: Name of input surface.
        outfile: Output results in .1D format.
        plimit: Maximum length of path along surface in mm. Default is 50 mm.
        dlimit: Maximum length of euclidean distance in mm. Default is 1000 mm.
        prefix: Output results into a proper surface-based dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SampBiasOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SAMP_BIAS_METADATA)
    cargs = []
    cargs.append("SampBias")
    cargs.extend([
        "-spec",
        execution.input_file(specfile)
    ])
    cargs.extend([
        "-surf",
        surfname
    ])
    if plimit is not None:
        cargs.extend([
            "-plimit",
            str(plimit)
        ])
    if dlimit is not None:
        cargs.extend([
            "-dlimit",
            str(dlimit)
        ])
    cargs.extend([
        "-out",
        outfile
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    ret = SampBiasOutputs(
        root=execution.output_file("."),
        out_1_d=execution.output_file(outfile + ".1D"),
        out_prefix=execution.output_file(prefix) if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SAMP_BIAS_METADATA",
    "SampBiasOutputs",
    "samp_bias",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIRST_ROI_SLICESDIR_METADATA = Metadata(
    id="e88bcb78f430d93578062447bcf9710d9aaf9023.boutiques",
    name="first_roi_slicesdir",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FirstRoiSlicesdirOutputs(typing.NamedTuple):
    """
    Output object returned when calling `first_roi_slicesdir(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    t1_slicesdir: OutputPathType
    """Generated slice directory for the input T1 images"""
    label_slicesdir: OutputPathType
    """Generated slice directory for the input label images"""


def first_roi_slicesdir(
    input_t1_images: str,
    input_label_images: str,
    runner: Runner | None = None,
) -> FirstRoiSlicesdirOutputs:
    """
    A utility for generating slice directories for FIRST-ROI.
    
    Author: FMRIB Centre, Oxford University
    
    Args:
        input_t1_images: Input T1-weighted images of the brain\
            (pattern-matched); for example, *_t1.nii.gz.
        input_label_images: Input label images corresponding to the T1 images\
            (pattern-matched); for example, *_L_Hipp_first.nii.gz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FirstRoiSlicesdirOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIRST_ROI_SLICESDIR_METADATA)
    cargs = []
    cargs.append("first_roi_slicesdir")
    cargs.append(input_t1_images)
    cargs.append(input_label_images)
    ret = FirstRoiSlicesdirOutputs(
        root=execution.output_file("."),
        t1_slicesdir=execution.output_file(input_t1_images + "_slicesdir"),
        label_slicesdir=execution.output_file(input_label_images + "_slicesdir"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIRST_ROI_SLICESDIR_METADATA",
    "FirstRoiSlicesdirOutputs",
    "first_roi_slicesdir",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PREWHITEN_METADATA = Metadata(
    id="93a98add87a31c04e0e49053a0e4eb6908676f51.boutiques",
    name="prewhiten",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PrewhitenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `prewhiten(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType | None
    """Output files generated in the specified output directory"""


def prewhiten(
    feat_directory: str,
    output_directory: str | None = None,
    runner: Runner | None = None,
) -> PrewhitenOutputs:
    """
    Prewhitening tool for FEAT directories.
    
    Args:
        feat_directory: Input FEAT directory.
        output_directory: Change output directory from default of input FEAT\
            directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PrewhitenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PREWHITEN_METADATA)
    cargs = []
    cargs.append("prewhiten")
    cargs.append(feat_directory)
    if output_directory is not None:
        cargs.extend([
            "-o",
            output_directory
        ])
    ret = PrewhitenOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_directory + "/*") if (output_directory is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PREWHITEN_METADATA",
    "PrewhitenOutputs",
    "prewhiten",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ZIP_SPEC_FILE_METADATA = Metadata(
    id="b648eb124c037c04f29cb50aa9718436909680bc.boutiques",
    name="zip-spec-file",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class ZipSpecFileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `zip_spec_file(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def zip_spec_file(
    spec_file: str,
    extract_folder: str,
    zip_file: str,
    opt_base_dir_directory: str | None = None,
    opt_skip_missing: bool = False,
    runner: Runner | None = None,
) -> ZipSpecFileOutputs:
    """
    Zip a spec file and its data files.
    
    If zip-file already exists, it will be overwritten. If -base-dir is not
    specified, the directory containing the spec file is used for the base
    directory. The spec file must contain only relative paths, and no data files
    may be outside the base directory. Scene files inside spec files are not
    checked for what files they reference, ensure that all data files referenced
    by the scene files are also referenced by the spec file.
    
    Author: Washington University School of Medicin
    
    Args:
        spec_file: the specification file to add to zip file.
        extract_folder: the name of the folder created when the zip file is\
            unzipped.
        zip_file: out - the zip file that will be created.
        opt_base_dir_directory: specify a directory that all data files are\
            somewhere within, this will become the root of the zipfile's directory\
            structure: the directory.
        opt_skip_missing: any missing files will generate only warnings, and\
            the zip file will be created anyway.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZipSpecFileOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ZIP_SPEC_FILE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-zip-spec-file")
    cargs.append(spec_file)
    cargs.append(extract_folder)
    cargs.append(zip_file)
    if opt_base_dir_directory is not None:
        cargs.extend([
            "-base-dir",
            opt_base_dir_directory
        ])
    if opt_skip_missing:
        cargs.append("-skip-missing")
    ret = ZipSpecFileOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ZIP_SPEC_FILE_METADATA",
    "ZipSpecFileOutputs",
    "zip_spec_file",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BRICK_STAT_METADATA = Metadata(
    id="cd1278790e5222b357489bd257cf57d97ce7fdbf.boutiques",
    name="3dBrickStat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBrickStatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_brick_stat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    console_output: OutputPathType
    """Console output of computed statistics"""


def v_3d_brick_stat(
    dataset: str,
    runner: Runner | None = None,
) -> V3dBrickStatOutputs:
    """
    Compute voxel statistics of an input dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dBrickStat.html
    
    Args:
        dataset: Input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBrickStatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BRICK_STAT_METADATA)
    cargs = []
    cargs.append("3dBrickStat")
    cargs.append("[OPTIONS]")
    cargs.append(dataset)
    ret = V3dBrickStatOutputs(
        root=execution.output_file("."),
        console_output=execution.output_file("output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBrickStatOutputs",
    "V_3D_BRICK_STAT_METADATA",
    "v_3d_brick_stat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_ERODE_METADATA = Metadata(
    id="d3b8b44bdde6181bba5681dd1a66c8288edb477e.boutiques",
    name="cifti-erode",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiErodeLeftSurface:
    """
    specify the left surface to use.
    """
    surface: InputPathType
    """the left surface file"""
    opt_left_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the left surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_left_corrected_areas_area_metric is not None:
            cargs.extend([
                "-left-corrected-areas",
                execution.input_file(self.opt_left_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiErodeRightSurface:
    """
    specify the right surface to use.
    """
    surface: InputPathType
    """the right surface file"""
    opt_right_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the right surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_right_corrected_areas_area_metric is not None:
            cargs.extend([
                "-right-corrected-areas",
                execution.input_file(self.opt_right_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiErodeCerebellumSurface:
    """
    specify the cerebellum surface to use.
    """
    surface: InputPathType
    """the cerebellum surface file"""
    opt_cerebellum_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the cerebellum
    surface: the corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_cerebellum_corrected_areas_area_metric is not None:
            cargs.extend([
                "-cerebellum-corrected-areas",
                execution.input_file(self.opt_cerebellum_corrected_areas_area_metric)
            ])
        return cargs


class CiftiErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_erode(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_erode(
    cifti_in: InputPathType,
    direction: str,
    surface_distance: float,
    volume_distance: float,
    cifti_out: str,
    left_surface: CiftiErodeLeftSurface | None = None,
    right_surface: CiftiErodeRightSurface | None = None,
    cerebellum_surface: CiftiErodeCerebellumSurface | None = None,
    opt_merged_volume: bool = False,
    runner: Runner | None = None,
) -> CiftiErodeOutputs:
    """
    Erode a cifti file.
    
    For all data values that are empty (for label data, unlabeled, for other
    data, zero), set the surrounding values to empty. The surrounding values are
    defined as the immediate neighbors and all values in the same structure
    within the specified distance (-merged-volume treats all voxels as one
    structure).
    
    The -*-corrected-areas options are intended for eroding on group average
    surfaces, but it is only an approximate correction.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_in: the input cifti file.
        direction: which dimension to dilate along, ROW or COLUMN.
        surface_distance: the distance to dilate on surfaces, in mm.
        volume_distance: the distance to dilate in the volume, in mm.
        cifti_out: the output cifti file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiErodeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ERODE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-erode")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(direction)
    cargs.append(str(surface_distance))
    cargs.append(str(volume_distance))
    cargs.append(cifti_out)
    if left_surface is not None:
        cargs.extend(left_surface.run(execution))
    if right_surface is not None:
        cargs.extend(right_surface.run(execution))
    if cerebellum_surface is not None:
        cargs.extend(cerebellum_surface.run(execution))
    if opt_merged_volume:
        cargs.append("-merged-volume")
    ret = CiftiErodeOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_ERODE_METADATA",
    "CiftiErodeCerebellumSurface",
    "CiftiErodeLeftSurface",
    "CiftiErodeOutputs",
    "CiftiErodeRightSurface",
    "cifti_erode",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_SMOOTH_METADATA = Metadata(
    id="b6ecd56b373e2b6037ad05649b420c51b2bdd92f.boutiques",
    name="SurfSmooth",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfSmoothOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_smooth(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Name of the output file."""


def surf_smooth(
    runner: Runner | None = None,
) -> SurfSmoothOutputs:
    """
    Tool for smoothing data on surfaces using various methods.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfSmooth.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfSmoothOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_SMOOTH_METADATA)
    cargs = []
    cargs.append("SurfSmooth")
    cargs.append("<-SURF_1>")
    cargs.append("<-met")
    cargs.append("method>")
    cargs.append("[PARAMETERS]")
    ret = SurfSmoothOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_SMOOTH_METADATA",
    "SurfSmoothOutputs",
    "surf_smooth",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_FIND_CLUSTERS_METADATA = Metadata(
    id="0bded5a79750b4b6439b0a638ace9eb0194bb652.boutiques",
    name="cifti-find-clusters",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiFindClustersLeftSurface:
    """
    specify the left surface to use.
    """
    surface: InputPathType
    """the left surface file"""
    opt_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_corrected_areas_area_metric is not None:
            cargs.extend([
                "-corrected-areas",
                execution.input_file(self.opt_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiFindClustersRightSurface:
    """
    specify the right surface to use.
    """
    surface: InputPathType
    """the right surface file"""
    opt_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_corrected_areas_area_metric is not None:
            cargs.extend([
                "-corrected-areas",
                execution.input_file(self.opt_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiFindClustersCerebellumSurface:
    """
    specify the cerebellum surface to use.
    """
    surface: InputPathType
    """the cerebellum surface file"""
    opt_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_corrected_areas_area_metric is not None:
            cargs.extend([
                "-corrected-areas",
                execution.input_file(self.opt_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiFindClustersSizeRatio:
    """
    ignore clusters smaller than a given fraction of the largest cluster in the
    structure.
    """
    surface_ratio: float
    """fraction of the structure's largest cluster area"""
    volume_ratio: float
    """fraction of the structure's largest cluster volume"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-size-ratio")
        cargs.append(str(self.surface_ratio))
        cargs.append(str(self.volume_ratio))
        return cargs


@dataclasses.dataclass
class CiftiFindClustersDistance:
    """
    ignore clusters further than a given distance from the largest cluster in
    the structure.
    """
    surface_distance: float
    """how far from the largest cluster a cluster can be, edge to edge, in mm"""
    volume_distance: float
    """how far from the largest cluster a cluster can be, edge to edge, in mm"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-distance")
        cargs.append(str(self.surface_distance))
        cargs.append(str(self.volume_distance))
        return cargs


class CiftiFindClustersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_find_clusters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""


def cifti_find_clusters(
    cifti: InputPathType,
    surface_value_threshold: float,
    surface_minimum_area: float,
    volume_value_threshold: float,
    volume_minimum_size: float,
    direction: str,
    cifti_out: str,
    opt_less_than: bool = False,
    left_surface: CiftiFindClustersLeftSurface | None = None,
    right_surface: CiftiFindClustersRightSurface | None = None,
    cerebellum_surface: CiftiFindClustersCerebellumSurface | None = None,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_merged_volume: bool = False,
    size_ratio: CiftiFindClustersSizeRatio | None = None,
    distance: CiftiFindClustersDistance | None = None,
    opt_start_startval: int | None = None,
    runner: Runner | None = None,
) -> CiftiFindClustersOutputs:
    """
    Filter clusters by area/volume.
    
    Outputs a cifti file with nonzero integers for all brainordinates within a
    large enough cluster, and zeros elsewhere. The integers denote cluster
    membership (by default, first cluster found will use value 1, second cluster
    2, etc). Cluster values are not reused across maps of the output, but
    instead keep counting up. The input cifti file must have a brain models
    mapping on the chosen dimension, columns for .dtseries, and either for
    .dconn. The ROI should have a brain models mapping along columns, exactly
    matching the mapping of the chosen direction in the input file. Data outside
    the ROI is ignored.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti: the input cifti.
        surface_value_threshold: threshold for surface data values.
        surface_minimum_area: threshold for surface cluster area, in mm^2.
        volume_value_threshold: threshold for volume data values.
        volume_minimum_size: threshold for volume cluster size, in mm^3.
        direction: which dimension to use for spatial information, ROW or\
            COLUMN.
        cifti_out: the output cifti.
        opt_less_than: find values less than <value-threshold>, rather than\
            greater.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_cifti_roi_roi_cifti: search only within regions of interest: the\
            regions to search within, as a cifti file.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        size_ratio: ignore clusters smaller than a given fraction of the\
            largest cluster in the structure.
        distance: ignore clusters further than a given distance from the\
            largest cluster in the structure.
        opt_start_startval: start labeling clusters from a value other than 1:\
            the value to give the first cluster found.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiFindClustersOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_FIND_CLUSTERS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-find-clusters")
    cargs.append(execution.input_file(cifti))
    cargs.append(str(surface_value_threshold))
    cargs.append(str(surface_minimum_area))
    cargs.append(str(volume_value_threshold))
    cargs.append(str(volume_minimum_size))
    cargs.append(direction)
    cargs.append(cifti_out)
    if opt_less_than:
        cargs.append("-less-than")
    if left_surface is not None:
        cargs.extend(left_surface.run(execution))
    if right_surface is not None:
        cargs.extend(right_surface.run(execution))
    if cerebellum_surface is not None:
        cargs.extend(cerebellum_surface.run(execution))
    if opt_cifti_roi_roi_cifti is not None:
        cargs.extend([
            "-cifti-roi",
            execution.input_file(opt_cifti_roi_roi_cifti)
        ])
    if opt_merged_volume:
        cargs.append("-merged-volume")
    if size_ratio is not None:
        cargs.extend(size_ratio.run(execution))
    if distance is not None:
        cargs.extend(distance.run(execution))
    if opt_start_startval is not None:
        cargs.extend([
            "-start",
            str(opt_start_startval)
        ])
    ret = CiftiFindClustersOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_FIND_CLUSTERS_METADATA",
    "CiftiFindClustersCerebellumSurface",
    "CiftiFindClustersDistance",
    "CiftiFindClustersLeftSurface",
    "CiftiFindClustersOutputs",
    "CiftiFindClustersRightSurface",
    "CiftiFindClustersSizeRatio",
    "cifti_find_clusters",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSIZE_METADATA = Metadata(
    id="0aa7e6fbb81dbdb0e85b1f0d56cc9743a42d862e.boutiques",
    name="fslsize",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslsizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslsize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslsize(
    input_file: InputPathType,
    short_format_flag: bool = False,
    runner: Runner | None = None,
) -> FslsizeOutputs:
    """
    Tool to output the size of an image file in FSL.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        input_file: Input image file.
        short_format_flag: Output using short format (one line).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslsizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSIZE_METADATA)
    cargs = []
    cargs.append("fslsize")
    cargs.append(execution.input_file(input_file))
    if short_format_flag:
        cargs.append("-s")
    ret = FslsizeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSIZE_METADATA",
    "FslsizeOutputs",
    "fslsize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_DYADIC_VECTORS_METADATA = Metadata(
    id="b4de8521b0d728a2cfd51b34e8ee2f002547c807.boutiques",
    name="make_dyadic_vectors",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MakeDyadicVectorsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_dyadic_vectors(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file containing the generated dyadic vectors"""


def make_dyadic_vectors(
    theta_vol: InputPathType,
    phi_vol: InputPathType,
    output: str,
    mask: InputPathType | None = None,
    perc: float | None = None,
    runner: Runner | None = None,
) -> MakeDyadicVectorsOutputs:
    """
    Generate dyadic vectors from theta and phi volumes.
    
    Author: Unknown
    
    Args:
        theta_vol: Theta volume input file.
        phi_vol: Phi volume input file.
        output: Output file.
        mask: Mask input file (optional).
        perc: Percentage angle of the output cone of uncertainty (output will\
            be in degrees).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeDyadicVectorsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_DYADIC_VECTORS_METADATA)
    cargs = []
    cargs.append("make_dyadic_vectors")
    cargs.append(execution.input_file(theta_vol))
    cargs.append(execution.input_file(phi_vol))
    if mask is not None:
        cargs.append(execution.input_file(mask))
    cargs.append(output)
    if perc is not None:
        cargs.append(str(perc))
    ret = MakeDyadicVectorsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_DYADIC_VECTORS_METADATA",
    "MakeDyadicVectorsOutputs",
    "make_dyadic_vectors",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AFNI_REFACER_MAKE_MASTER_METADATA = Metadata(
    id="d2b95955add5ec1c7ee9c902b86d10ff4ae67032.boutiques",
    name="@afni_refacer_make_master",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAfniRefacerMakeMasterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__afni_refacer_make_master(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_shell_dataset: OutputPathType
    """Output dataset containing the average 'face' (non-brain tissue)."""


def v__afni_refacer_make_master(
    input_datasets: list[InputPathType],
    runner: Runner | None = None,
) -> VAfniRefacerMakeMasterOutputs:
    """
    This script makes a new mask/shell dataset for use with @afni_refacer_run by
    averaging 'faces' (non-brain tissue) from input datasets.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@afni_refacer_make_master.html
    
    Args:
        input_datasets: List of T1-weighted datasets that have NOT been\
            skull-stripped, defaced, or refaced.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAfniRefacerMakeMasterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AFNI_REFACER_MAKE_MASTER_METADATA)
    cargs = []
    cargs.append("@afni_refacer_make_master")
    cargs.extend([execution.input_file(f) for f in input_datasets])
    ret = VAfniRefacerMakeMasterOutputs(
        root=execution.output_file("."),
        output_shell_dataset=execution.output_file("afni_refacer_shell.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAfniRefacerMakeMasterOutputs",
    "V__AFNI_REFACER_MAKE_MASTER_METADATA",
    "v__afni_refacer_make_master",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EPI_REG_METADATA = Metadata(
    id="34fef22f93551d0f4b6ff6e880c97fd91c9d9107.boutiques",
    name="epi_reg",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class EpiRegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `epi_reg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    epi2str_inv: OutputPathType
    """Rigid structural-to-epi transform."""
    epi2str_mat: OutputPathType
    """Rigid epi-to-structural transform."""
    fmap2epi_mat: OutputPathType
    """Rigid fieldmap-to-epi transform."""
    fmap2str_mat: OutputPathType
    """Rigid fieldmap-to-structural transform."""
    fmap_epi: OutputPathType
    """Fieldmap in epi space."""
    fmap_str: OutputPathType
    """Fieldmap in structural space."""
    fmapmag_str: OutputPathType
    """Fieldmap magnitude image in structural space."""
    fullwarp: OutputPathType
    """Warpfield to unwarp epi and transform into structural space."""
    out_1vol: OutputPathType
    """Unwarped and coregistered single volume."""
    out_file: OutputPathType
    """Unwarped and coregistered epi input."""
    seg: OutputPathType
    """White matter, gray matter, csf segmentation."""
    shiftmap: OutputPathType
    """Shiftmap in epi space."""
    wmedge: OutputPathType
    """White matter edges for visualization."""
    wmseg_outfile: OutputPathType
    """White matter segmentation used in flirt bbr."""


def epi_reg(
    epi: InputPathType,
    t1_head: InputPathType,
    t1_brain: InputPathType,
    out_base_name: str,
    echospacing: float | None = None,
    fmap: InputPathType | None = None,
    fmapmag: InputPathType | None = None,
    fmapmagbrain: InputPathType | None = None,
    no_clean: bool = False,
    no_fmapreg: bool = False,
    pedir: typing.Literal["x", "y", "z", "-x", "-y", "-z"] | None = None,
    weight_image: InputPathType | None = None,
    wmseg: InputPathType | None = None,
    runner: Runner | None = None,
) -> EpiRegOutputs:
    """
    Runs FSL epi_reg script for simultaneous coregistration and fieldmap unwarping.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT/UserGuide#epi_reg
    
    Args:
        epi: EPI Nifti image.
        t1_head: Wholehead T1 image.
        t1_brain: Brain-extracted T1 image.
        out_base_name: Output base name.
        echospacing: Effective epi echo spacing (sometimes called dwell time) -\
            in seconds.
        fmap: Fieldmap image (in rad/s).
        fmapmag: Fieldmap magnitude image - wholehead.
        fmapmagbrain: Fieldmap magnitude image - brain extracted.
        no_clean: Do not clean up intermediate files.
        no_fmapreg: Do not perform registration of fmap to t1 (use if fmap\
            already registered).
        pedir: 'x' or 'y' or 'z' or '-x' or '-y' or '-z'. Phase encoding\
            direction, dir = x/y/z/-x/-y/-z.
        weight_image: Weighting image (in t1 space).
        wmseg: White matter segmentation of t1 image, has to be named like the\
            t1brain and end on _wmseg.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EpiRegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EPI_REG_METADATA)
    cargs = []
    cargs.append("epi_reg")
    cargs.append("--epi=" + execution.input_file(epi))
    cargs.append("--t1=" + execution.input_file(t1_head))
    cargs.append("--t1brain=" + execution.input_file(t1_brain))
    cargs.append("--out=" + out_base_name)
    if echospacing is not None:
        cargs.append("--echospacing=" + str(echospacing))
    if fmap is not None:
        cargs.append("--fmap=" + execution.input_file(fmap))
    if fmapmag is not None:
        cargs.append("--fmapmag=" + execution.input_file(fmapmag))
    if fmapmagbrain is not None:
        cargs.append("--fmapmagbrain=" + execution.input_file(fmapmagbrain))
    if no_clean:
        cargs.append("--noclean")
    if no_fmapreg:
        cargs.append("--nofmapreg")
    if pedir is not None:
        cargs.append("--pedir=" + pedir)
    if weight_image is not None:
        cargs.append("--weight=" + execution.input_file(weight_image))
    if wmseg is not None:
        cargs.append("--wmseg=" + execution.input_file(wmseg))
    ret = EpiRegOutputs(
        root=execution.output_file("."),
        epi2str_inv=execution.output_file("epi2str_inv.mat"),
        epi2str_mat=execution.output_file("epi2struct.mat"),
        fmap2epi_mat=execution.output_file("fmap2epi.mat"),
        fmap2str_mat=execution.output_file("fmap2str.mat"),
        fmap_epi=execution.output_file("fmap_epi.nii.gz"),
        fmap_str=execution.output_file("fmap_str.nii.gz"),
        fmapmag_str=execution.output_file("fmapmag_str.nii.gz"),
        fullwarp=execution.output_file("fullwarp.nii.gz"),
        out_1vol=execution.output_file("out_1vol.nii.gz"),
        out_file=execution.output_file(out_base_name + ".nii.gz"),
        seg=execution.output_file(out_base_name + "_fast_seg.nii.gz"),
        shiftmap=execution.output_file("shiftmap.nii.gz"),
        wmedge=execution.output_file(out_base_name + "_fast_wmedge.nii.gz"),
        wmseg_outfile=execution.output_file(out_base_name + "_fast_wmseg.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EPI_REG_METADATA",
    "EpiRegOutputs",
    "epi_reg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DREFIT_METADATA = Metadata(
    id="42d78141a8201ea0512b64bbbe12f75204ab2092.boutiques",
    name="3drefit",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3drefitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3drefit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output file."""


def v_3drefit(
    in_file: InputPathType,
    atrcopy: list[str] | None = None,
    atrfloat: list[str] | None = None,
    atrint: list[str] | None = None,
    atrstring: list[str] | None = None,
    deoblique: bool = False,
    duporigin_file: InputPathType | None = None,
    nosaveatr: bool = False,
    saveatr: bool = False,
    space: typing.Literal["TLRC", "MNI", "ORIG"] | None = None,
    xdel: float | None = None,
    xorigin: str | None = None,
    xyzscale: float | None = None,
    ydel: float | None = None,
    yorigin: str | None = None,
    zdel: float | None = None,
    zorigin: str | None = None,
    runner: Runner | None = None,
) -> V3drefitOutputs:
    """
    Changes some of the information inside a 3D dataset's header.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3drefit.html
    
    Args:
        in_file: Input file to 3drefit.
        atrcopy: (file, string). Copy afni header attribute from the given file\
            into the header of the dataset(s) being modified. for more information\
            on afni header attributes, see documentation file readme.attributes.\
            more than one '-atrcopy' option can be used. for afni advanced users\
            only. do not use -atrcopy or -atrstring with other modification\
            options. see also -copyaux.
        atrfloat: (a string, a string). Create or modify floating point\
            attributes. the input values may be specified as a single string in\
            quotes or as a 1d filename or string, example '1 0.2 0 0 -0.2 1 0 0 0 0\
            1 0' or flipz.1d or '1d:1,0.2,2@0,-0.2,1,2@0,2@0,1,0'.
        atrint: (a string, a string). Create or modify integer attributes. the\
            input values may be specified as a single string in quotes or as a 1d\
            filename or string, example '1 0 0 0 0 1 0 0 0 0 1 0' or flipz.1d or\
            '1d:1,0,2@0,-0,1,2@0,2@0,1,0'.
        atrstring: (a string, a string). Copy the last given string into the\
            dataset(s) being modified, giving it the attribute name given by the\
            last string.to be safe, the last string should be in quotes.
        deoblique: Replace current transformation matrix with cardinal matrix.
        duporigin_file: Copies the xorigin, yorigin, and zorigin values from\
            the header of the given dataset.
        nosaveatr: Opposite of -saveatr.
        saveatr: (default) copy the attributes that are known to afni into the\
            dset->dblk structure thereby forcing changes to known attributes to be\
            present in the output. this option only makes sense with -atrcopy.
        space: 'tlrc' or 'mni' or 'orig'. Associates the dataset with a\
            specific template type, e.g. tlrc, mni, orig.
        xdel: New x voxel dimension in mm.
        xorigin: X distance for edge voxel offset.
        xyzscale: Scale the size of the dataset voxels by the given factor.
        ydel: New y voxel dimension in mm.
        yorigin: Y distance for edge voxel offset.
        zdel: New z voxel dimension in mm.
        zorigin: Z distance for edge voxel offset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3drefitOutputs`).
    """
    if atrcopy is not None and (len(atrcopy) != 2): 
        raise ValueError(f"Length of 'atrcopy' must be 2 but was {len(atrcopy)}")
    if atrfloat is not None and (len(atrfloat) != 2): 
        raise ValueError(f"Length of 'atrfloat' must be 2 but was {len(atrfloat)}")
    if atrint is not None and (len(atrint) != 2): 
        raise ValueError(f"Length of 'atrint' must be 2 but was {len(atrint)}")
    if atrstring is not None and (len(atrstring) != 2): 
        raise ValueError(f"Length of 'atrstring' must be 2 but was {len(atrstring)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DREFIT_METADATA)
    cargs = []
    cargs.append("3drefit")
    cargs.append(execution.input_file(in_file))
    if atrcopy is not None:
        cargs.extend([
            "-atrcopy",
            *atrcopy
        ])
    if atrfloat is not None:
        cargs.extend([
            "-atrfloat",
            *atrfloat
        ])
    if atrint is not None:
        cargs.extend([
            "-atrint",
            *atrint
        ])
    if atrstring is not None:
        cargs.extend([
            "-atrstring",
            *atrstring
        ])
    if deoblique:
        cargs.append("-deoblique")
    if duporigin_file is not None:
        cargs.extend([
            "-duporigin",
            execution.input_file(duporigin_file)
        ])
    if nosaveatr:
        cargs.append("-nosaveatr")
    if saveatr:
        cargs.append("-saveatr")
    if space is not None:
        cargs.extend([
            "-space",
            space
        ])
    if xdel is not None:
        cargs.extend([
            "-xdel",
            str(xdel)
        ])
    if xorigin is not None:
        cargs.extend([
            "-xorigin",
            xorigin
        ])
    if xyzscale is not None:
        cargs.extend([
            "-xyzscale",
            str(xyzscale)
        ])
    if ydel is not None:
        cargs.extend([
            "-ydel",
            str(ydel)
        ])
    if yorigin is not None:
        cargs.extend([
            "-yorigin",
            yorigin
        ])
    if zdel is not None:
        cargs.extend([
            "-zdel",
            str(zdel)
        ])
    if zorigin is not None:
        cargs.extend([
            "-zorigin",
            zorigin
        ])
    ret = V3drefitOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3drefitOutputs",
    "V_3DREFIT_METADATA",
    "v_3drefit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_REG_METADATA = Metadata(
    id="fa899f6f488c1db24bf97c2552e452f45a1a6d51.boutiques",
    name="fsl_reg",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslRegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_reg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform_file: OutputPathType
    """Output transformation file"""


def fsl_reg(
    input_file: InputPathType,
    reference_file: InputPathType,
    output_file: str,
    estimate_only_flag: bool = False,
    affine_only_flag: bool = False,
    fnirt_fa_config_flag: bool = False,
    flirt_options: str | None = None,
    fnirt_options: str | None = None,
    runner: Runner | None = None,
) -> FslRegOutputs:
    """
    Image registration using FSL tools.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FNIRT
    
    Args:
        input_file: Input image file.
        reference_file: Reference image file.
        output_file: Output transformation file.
        estimate_only_flag: Estimate transformation but don't apply it.
        affine_only_flag: Affine-only registration.
        fnirt_fa_config_flag: Use FNIRT config file optimised for FA data.
        flirt_options: Options to be passed onto flirt (inside double-quotes).
        fnirt_options: Options to be passed onto fnirt (inside double-quotes).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslRegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_REG_METADATA)
    cargs = []
    cargs.append("fsl_reg")
    cargs.append(execution.input_file(input_file))
    cargs.append(execution.input_file(reference_file))
    cargs.append(output_file)
    if estimate_only_flag:
        cargs.append("-e")
    if affine_only_flag:
        cargs.append("-a")
    if fnirt_fa_config_flag:
        cargs.append("-FA")
    if flirt_options is not None:
        cargs.extend([
            "-flirt",
            flirt_options
        ])
    if fnirt_options is not None:
        cargs.extend([
            "-fnirt",
            fnirt_options
        ])
    ret = FslRegOutputs(
        root=execution.output_file("."),
        output_transform_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_REG_METADATA",
    "FslRegOutputs",
    "fsl_reg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_FFT_METADATA = Metadata(
    id="851402de6e59bb412e16d2fd29f106f1673bae6d.boutiques",
    name="3dFFT",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dFftOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_fft(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output dataset generated by 3dFFT."""


def v_3d_fft(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dFftOutputs:
    """
    Performs the FFT of the input dataset in 3 directions (x, y, z) and produces the
    output dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dFFT.html
    
    Args:
        dataset: Input dataset (e.g., dataset.nii).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dFftOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_FFT_METADATA)
    cargs = []
    cargs.append("3dFFT")
    cargs.append("[--abs]")
    cargs.append("[--phase]")
    cargs.append("[--complex]")
    cargs.append("[--inverse]")
    cargs.append("[--Lx")
    cargs.append("X_LENGTH]")
    cargs.append("[--Ly")
    cargs.append("Y_LENGTH]")
    cargs.append("[--Lz")
    cargs.append("Z_LENGTH]")
    cargs.append("[--altIN]")
    cargs.append("[--altOUT]")
    cargs.append("[--input")
    cargs.append("INPUT_FILE]")
    cargs.append("[--prefix")
    cargs.append("PREFIX]")
    cargs.append(execution.input_file(dataset))
    ret = V3dFftOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file("[PREFIX].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dFftOutputs",
    "V_3D_FFT_METADATA",
    "v_3d_fft",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SPACE_TIME_CORR_METADATA = Metadata(
    id="b0ec9131465906bbbb276caa42352d6789463dbb.boutiques",
    name="3dSpaceTimeCorr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSpaceTimeCorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_space_time_corr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Output data set with space-time correlation coefficients."""


def v_3d_space_time_corr(
    inset_a: InputPathType,
    inset_b: InputPathType,
    prefix: str,
    mask: InputPathType | None = None,
    out_zcorr: bool = False,
    freeze_inset_a_ijk: list[float] | None = None,
    freeze_inset_a_xyz: list[float] | None = None,
    runner: Runner | None = None,
) -> V3dSpaceTimeCorrOutputs:
    """
    Calculates correlation coefficients between two 4D datasets using space+time
    patterns.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dSpaceTimeCorr.html
    
    Args:
        inset_a: First 4D data set.
        inset_b: Second 4D data set. Must have the same spatial dimensions and\
            number of time points as insetA.
        prefix: Output filename/base.
        mask: Optional mask for calculations. Recommended for speed and\
            interpretability.
        out_zcorr: Switch to output Fisher Z transform of spatial map\
            correlation instead of Pearson r values.
        freeze_inset_a_ijk: Freeze the seed voxel location in the insetA data\
            set using ijk indices while the seed location in insetB moves\
            throughout the volume or mask. Provide three ijk values.
        freeze_inset_a_xyz: Freeze the seed voxel location in the insetA data\
            set using xyz coordinates while the seed location in insetB moves\
            throughout the volume or mask. Provide three xyz values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSpaceTimeCorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SPACE_TIME_CORR_METADATA)
    cargs = []
    cargs.append("3dSpaceTimeCorr")
    cargs.extend([
        "-insetA",
        execution.input_file(inset_a)
    ])
    cargs.extend([
        "-insetB",
        execution.input_file(inset_b)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if out_zcorr:
        cargs.append("-out_Zcorr")
    if freeze_inset_a_ijk is not None:
        cargs.extend([
            "-freeze_insetA_ijk",
            *map(str, freeze_inset_a_ijk)
        ])
    if freeze_inset_a_xyz is not None:
        cargs.extend([
            "-freeze_insetA_xyz",
            *map(str, freeze_inset_a_xyz)
        ])
    ret = V3dSpaceTimeCorrOutputs(
        root=execution.output_file("."),
        output=execution.output_file(prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSpaceTimeCorrOutputs",
    "V_3D_SPACE_TIME_CORR_METADATA",
    "v_3d_space_time_corr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NET_CORR_METADATA = Metadata(
    id="4e843c9d25d6dd2740cb3fb713219ba61ca439c5.boutiques",
    name="3dNetCorr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNetCorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_net_corr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_netcc: OutputPathType
    """Output correlation matrix file for network 000"""
    output_netts: OutputPathType
    """Output mean time series per ROI for network 000"""
    output_niml: OutputPathType
    """NIML/SUMA-esque file for visualizing connectivity info in a 3D brain for
    network 000"""
    output_roidat: OutputPathType
    """Columns contain information for each ROI in the used mask."""
    output_mask_nnull: OutputPathType
    """Mask of non-null time series"""
    output_indiv: OutputPathType
    """Directory containing individual time series files for network 000"""
    output_binary_mask_nnull: OutputPathType
    """Binary mask of the non-null time series"""


def v_3d_net_corr(
    prefix: str,
    inset: InputPathType,
    in_rois: InputPathType,
    fish_z: bool = False,
    part_corr: bool = False,
    ts_out: bool = False,
    ts_label: bool = False,
    ts_indiv: bool = False,
    ts_wb_corr: bool = False,
    ts_wb_z: bool = False,
    weight_ts: InputPathType | None = None,
    weight_corr: InputPathType | None = None,
    ts_wb_strlabel: bool = False,
    nifti: bool = False,
    output_mask_nonnull: bool = False,
    push_thru_many_zeros: bool = False,
    allow_roi_zeros: bool = False,
    automask_off: bool = False,
    ignore_lt: bool = False,
    runner: Runner | None = None,
) -> V3dNetCorrOutputs:
    """
    Compute correlation matrix of a set of ROIs based on mean time series.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dNetCorr.html
    
    Args:
        prefix: Output file name prefix.
        inset: Time series file (4D data set).
        in_rois: Input a set of ROIs each labelled with distinct integers.\
            Multiple subbricks can be input, each will be treated as a separate\
            network.
        fish_z: Output Fisher Z-transform matrix along with correlation matrix.
        part_corr: Output the partial correlation matrix.
        ts_out: Output the mean time series of the ROIs.
        ts_label: Insert the integer ROI label at the start of each line of the\
            *.netts file created.
        ts_indiv: Create a directory for each network that contains the average\
            time series for each ROI in individual files.
        ts_wb_corr: Perform whole brain correlation for each ROI's average time\
            series and output as Pearson 'r' values.
        ts_wb_z: Perform whole brain correlation for each ROI's average time\
            series and output as Fisher transformed Z-scores.
        weight_ts: Input a 1D file of weights to be applied multiplicatively to\
            each ROI's average time series.
        weight_corr: Input a 1D file of weights to estimate a weighted Pearson\
            Correlation.
        ts_wb_strlabel: Apply string labels to the WB correlation/Z-score\
            output files.
        nifti: Output any correlation map files as NIFTI files.
        output_mask_nonnull: Output mask of non-null time series.
        push_thru_many_zeros: Push through the calculation even if any ROI\
            contains more than 10 percent of voxels with null time series.
        allow_roi_zeros: Allow ROIs to have all-zero time series.
        automask_off: Disable internal automasking of where time series are not\
            uniformly zero.
        ignore_lt: Ignore any label table labels in the '-in_rois' file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNetCorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NET_CORR_METADATA)
    cargs = []
    cargs.append("3dNetCorr")
    cargs.append("-prefix")
    cargs.append(prefix)
    cargs.append("-inset")
    cargs.append(execution.input_file(inset))
    cargs.append("-in_rois")
    cargs.append(execution.input_file(in_rois))
    cargs.append("[MASK_OPTION]")
    if fish_z:
        cargs.append("-fish_z")
    if part_corr:
        cargs.append("-part_corr")
    if ts_out:
        cargs.append("-ts_out")
    if ts_label:
        cargs.append("-ts_label")
    if ts_indiv:
        cargs.append("-ts_indiv")
    if ts_wb_corr:
        cargs.append("-ts_wb_corr")
    if ts_wb_z:
        cargs.append("-ts_wb_Z")
    if weight_ts is not None:
        cargs.extend([
            "-weight_ts",
            execution.input_file(weight_ts)
        ])
    if weight_corr is not None:
        cargs.extend([
            "-weight_corr",
            execution.input_file(weight_corr)
        ])
    if ts_wb_strlabel:
        cargs.append("-ts_wb_strlabel")
    if nifti:
        cargs.append("-nifti")
    if output_mask_nonnull:
        cargs.append("-output_mask_nonnull")
    if push_thru_many_zeros:
        cargs.append("-push_thru_many_zeros")
    if allow_roi_zeros:
        cargs.append("-allow_roi_zeros")
    if automask_off:
        cargs.append("-automask_off")
    if ignore_lt:
        cargs.append("-ignore_LT")
    ret = V3dNetCorrOutputs(
        root=execution.output_file("."),
        output_netcc=execution.output_file(prefix + "_000.netcc"),
        output_netts=execution.output_file(prefix + "_000.netts"),
        output_niml=execution.output_file(prefix + "_000.niml.dset"),
        output_roidat=execution.output_file(prefix + ".roidat"),
        output_mask_nnull=execution.output_file(prefix + "_mask_nnull"),
        output_indiv=execution.output_file(prefix + "_000_INDIV"),
        output_binary_mask_nnull=execution.output_file("PREFIX_mask_nnull"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNetCorrOutputs",
    "V_3D_NET_CORR_METADATA",
    "v_3d_net_corr",
]
